package com.jd.jd_ironsource_plugin

import android.app.Activity
import android.util.Log
import androidx.annotation.NonNull
import com.ironsource.mediationsdk.IronSource
import com.ironsource.mediationsdk.logger.IronSourceError
import com.ironsource.mediationsdk.sdk.OfferwallListener

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

/** JdIronsourcePlugin */
class JdIronsourcePlugin : FlutterPlugin, MethodCallHandler, ActivityAware {
    private lateinit var channel: MethodChannel
    private lateinit var activity: Activity

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "jd_ironsource_plugin")
        channel.setMethodCallHandler(this)
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            "init" -> {
                val appKey = call.argument<String>("appKey") ?: ""
                IronSource.init(activity, appKey)
            }


            "showOfferWall" -> {
                IronSource.showOfferwall()
            }

            "setOfferWallListener" -> {
                IronSource.setOfferwallListener(object : OfferwallListener {

                    //积分墙状态变化，为true可调用，showOfferwall
                    override fun onOfferwallAvailable(isAvailable: Boolean) {
                    }

                    //加载成功调用
                    override fun onOfferwallOpened() {
                        channel.invokeMethod("setOfferWallListener", "onOfferWallOpened")
                    }

                    //打印错误信息
                    override fun onOfferwallShowFailed(error: IronSourceError) {
                    }

                    //获取奖励回调
                    override fun onOfferwallAdCredited(credits: Int, totalCredits: Int, totalCreditsFlag: Boolean): Boolean {
                        return true
                    }

                    //加钱回调
                    override fun onGetOfferwallCreditsFailed(error: IronSourceError) {
                    }

                    //关闭回调
                    override fun onOfferwallClosed() {
                        channel.invokeMethod("setOfferWallListener", "onOfferWallClosed")
                    }
                })
            }

            else -> {
                result.notImplemented()
            }
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }

    override fun onDetachedFromActivity() {
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        activity = binding.activity
    }

    override fun onDetachedFromActivityForConfigChanges() {
    }
}
